@@ -44,6 +44,7 @@ class AlertsSummary(BaseModel):
     o2_room_alerts: dict[str, bool] | None = None
     heater_alert: bool | None = None
     heater_camera_alerts: dict[str, bool] | None = None
+    engineering_override: bool = False
 
 
 class ConnectivityStatus:
@@ -68,10 +69,12 @@ class ActiveAlert(enum.Flag):
     ALERTS_UNAVAILABLE = enum.auto()
     DISCONNECTED = enum.auto()
     DOME_LOCKED = enum.auto()
+    IDLE = enum.auto()
+    ENGINEERING_OVERRIDE = enum.auto()
     UNKNOWN = enum.auto()
 
     ALWAYS_CLOSE = HUMIDITY | DEW_POINT | WIND | RAIN
-    NO_CLOSE = DOOR | E_STOPS
+    NO_CLOSE = DOOR | E_STOPS | ENGINEERING_OVERRIDE
 
 
 class AlertsMonitorTask(OverwatcherModuleTask["AlertsOverwatcher"]):
@@ -100,6 +103,10 @@ class AlertsMonitorTask(OverwatcherModuleTask["AlertsOverwatcher"]):
                 n_failures = 0
             finally:
                 if self.module.unavailable is False and n_failures >= 5:
+                    await self.module.notify(
+                        "Alerts data is unavailable.",
+                        level="critical",
+                    )
                     self.module.unavailable = True
 
             await asyncio.sleep(self.INTERVAL)
@@ -132,9 +139,10 @@ class AlertsOverwatcher(OverwatcherModule):
         self.connectivity = ConnectivityStatus()
 
         self.last_updated: float = 0.0
+        self.idle_since: float = 0.0
         self.unavailable: bool = False
 
-    def is_safe(self) -> tuple[bool, ActiveAlert]:
+    async def is_safe(self) -> tuple[bool, ActiveAlert]:
         """Determines whether it is safe to open."""
 
         if self.state is None:
@@ -144,6 +152,12 @@ class AlertsOverwatcher(OverwatcherModule):
         is_safe: bool = True
         active_alerts = ActiveAlert(0)
 
+        # Keep track of how long the overwatcher has been idle.
+        if self.overwatcher.state.idle and self.idle_since == 0:
+            self.idle_since = time()
+        else:
+            self.idle_since = 0
+
         if self.unavailable:
             self.log.warning("Alerts data is unavailable.")
             active_alerts |= ActiveAlert.ALERTS_UNAVAILABLE
@@ -211,6 +225,23 @@ class AlertsOverwatcher(OverwatcherModule):
             self.log.warning("O2 alert detected.")
             active_alerts |= ActiveAlert.O2
 
+        if is_safe and self.overwatcher.state.enabled and self.overwatcher.state.night:
+            # If it's safe to observe but we have been idle for a while, we
+            # raise an alert but do not change the is_safe status.
+            timeout = self.overwatcher.config["overwatcher.alerts.idle_timeout"] or 600
+            if self.idle_since > 0 and (time() - self.idle_since) > timeout:
+                await self.notify(
+                    f"Overwatcher has been idle for over {timeout:.0f} s.",
+                    min_time_between_repeat_notifications=300,
+                )
+                active_alerts |= ActiveAlert.IDLE
+
+        # If the engineering mode is enabled, we assume it's safe.
+        if self.state.engineering_override:
+            self.log.warning("Engineering mode is enabled.")
+            active_alerts |= ActiveAlert.ENGINEERING_OVERRIDE
+            is_safe = True
+
         return is_safe, active_alerts
 
     async def update_status(self) -> AlertsSummary:
